<?php
/**
 * Baroque theme customizer
 *
 * @package Baroque
 */

// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

class Baroque_Customize {
	/**
	 * Customize settings
	 *
	 * @var array
	 */
	protected $config = array();

	/**
	 * The class constructor
	 *
	 * @param array $config
	 */
	public function __construct( $config ) {
		$this->config = $config;

		if ( ! class_exists( 'Kirki' ) ) {
			return;
		}

		$this->register();
	}

	/**
	 * Register settings
	 */
	public function register() {
		/**
		 * Add the theme configuration
		 */
		if ( ! empty( $this->config['theme'] ) ) {
			Kirki::add_config(
				$this->config['theme'], array(
					'capability'  => 'edit_theme_options',
					'option_type' => 'theme_mod',
				)
			);
		}

		/**
		 * Add panels
		 */
		if ( ! empty( $this->config['panels'] ) ) {
			foreach ( $this->config['panels'] as $panel => $settings ) {
				Kirki::add_panel( $panel, $settings );
			}
		}

		/**
		 * Add sections
		 */
		if ( ! empty( $this->config['sections'] ) ) {
			foreach ( $this->config['sections'] as $section => $settings ) {
				Kirki::add_section( $section, $settings );
			}
		}

		/**
		 * Add fields
		 */
		if ( ! empty( $this->config['theme'] ) && ! empty( $this->config['fields'] ) ) {
			foreach ( $this->config['fields'] as $name => $settings ) {
				if ( ! isset( $settings['settings'] ) ) {
					$settings['settings'] = $name;
				}

				Kirki::add_field( $this->config['theme'], $settings );
			}
		}
	}

	/**
	 * Get config ID
	 *
	 * @return string
	 */
	public function get_theme() {
		return $this->config['theme'];
	}

	/**
	 * Get customize setting value
	 *
	 * @param string $name
	 *
	 * @return bool|string
	 */
	public function get_option( $name ) {

		$default = $this->get_option_default( $name );

		return get_theme_mod( $name, $default );
	}

	/**
	 * Get default option values
	 *
	 * @param $name
	 *
	 * @return mixed
	 */
	public function get_option_default( $name ) {
		if ( ! isset( $this->config['fields'][$name] ) ) {
			return false;
		}

		return isset( $this->config['fields'][$name]['default'] ) ? $this->config['fields'][$name]['default'] : false;
	}
}

/**
 * This is a short hand function for getting setting value from customizer
 *
 * @param string $name
 *
 * @return bool|string
 */
function baroque_get_option( $name ) {
	global $baroque_customize;

	if ( empty( $baroque_customize ) ) {
		return false;
	}

	if ( class_exists( 'Kirki' ) ) {
		$value = Kirki::get_option( $baroque_customize->get_theme(), $name );
	} else {
		$value = $baroque_customize->get_option( $name );
	}

	return apply_filters( 'baroque_get_option', $value, $name );
}

/**
 * Get default option values
 *
 * @param $name
 *
 * @return mixed
 */
function baroque_get_option_default( $name ) {
	global $baroque_customize;

	if ( empty( $baroque_customize ) ) {
		return false;
	}

	return $baroque_customize->get_option_default( $name );
}

/**
 * Move some default sections to `general` panel that registered by theme
 *
 * @param object $wp_customize
 */
function baroque_customize_modify( $wp_customize ) {
	$wp_customize->get_section( 'title_tagline' )->panel     = 'general';
	$wp_customize->get_section( 'static_front_page' )->panel = 'general';
}

add_action( 'customize_register', 'baroque_customize_modify' );

function baroque_customize_settings() {
	/**
	 * Customizer configuration
	 */

	$settings = array(
		'theme' => 'baroque',
	);

	$panels = array(
		'general'     => array(
			'priority' => 5,
			'title'    => esc_html__( 'General', 'baroque' ),
		),
		'typography'  => array(
			'priority' => 10,
			'title'    => esc_html__( 'Typography', 'baroque' ),
		),
		'styling'     => array(
			'priority' => 10,
			'title'    => esc_html__( 'Styling', 'baroque' ),
		),
		'header'      => array(
			'priority' => 10,
			'title'    => esc_html__( 'Header', 'baroque' ),
		),
		'page'        => array(
			'priority' => 10,
			'title'    => esc_html__( 'Page', 'baroque' ),
		),
		'blog'        => array(
			'title'      => esc_html__( 'Blog', 'baroque' ),
			'priority'   => 10,
			'capability' => 'edit_theme_options',
		),
		'portfolio'   => array(
			'title'      => esc_html__( 'Portfolio', 'baroque' ),
			'priority'   => 10,
			'capability' => 'edit_theme_options',
		),
		'service'   => array(
			'title'      => esc_html__( 'Service', 'baroque' ),
			'priority'   => 10,
			'capability' => 'edit_theme_options',
		),
		'woocommerce' => array(
			'priority' => 10,
			'title'    => esc_html__( 'Woocommerce', 'baroque' ),
		),
	);

	$sections = array(
		'image_sizes'                 => array(
			'title'       => esc_html__( 'Image Sizes', 'baroque' ),
			'description' => '',
			'priority'    => 210,
			'capability'  => 'edit_theme_options',
			'panel'       => 'general',
		),
		// Typography
		'font_families_typo'          => array(
			'title'       => esc_html__( 'Fonts Families', 'baroque' ),
			'description' => '',
			'priority'    => 210,
			'capability'  => 'edit_theme_options',
			'panel'       => 'typography',
		),
		'body_typo'                   => array(
			'title'       => esc_html__( 'Body', 'baroque' ),
			'description' => '',
			'priority'    => 210,
			'capability'  => 'edit_theme_options',
			'panel'       => 'typography',
		),
		'heading_typo'                => array(
			'title'       => esc_html__( 'Heading', 'baroque' ),
			'description' => '',
			'priority'    => 210,
			'capability'  => 'edit_theme_options',
			'panel'       => 'typography',
		),
		'header_typo'                 => array(
			'title'       => esc_html__( 'Header', 'baroque' ),
			'description' => '',
			'priority'    => 210,
			'capability'  => 'edit_theme_options',
			'panel'       => 'typography',
		),
		'footer_typo'                 => array(
			'title'       => esc_html__( 'Footer', 'baroque' ),
			'description' => '',
			'priority'    => 210,
			'capability'  => 'edit_theme_options',
			'panel'       => 'typography',
		),
		'menu_sidebar_typo'                 => array(
			'title'       => esc_html__( 'Menu Sidebar', 'baroque' ),
			'description' => '',
			'priority'    => 210,
			'capability'  => 'edit_theme_options',
			'panel'       => 'typography',
		),
		'header'                      => array(
			'title'       => esc_html__( 'Header', 'baroque' ),
			'description' => '',
			'priority'    => 10,
			'capability'  => 'edit_theme_options',
			'panel'       => 'header',
		),
		'logo'                        => array(
			'title'       => esc_html__( 'Logo', 'baroque' ),
			'description' => '',
			'priority'    => 10,
			'capability'  => 'edit_theme_options',
			'panel'       => 'header',
		),
		'canvas_menu'                 => array(
			'title'       => esc_html__( 'Canvas Menu', 'baroque' ),
			'description' => '',
			'priority'    => 10,
			'capability'  => 'edit_theme_options',
			'panel'       => 'header',
		),
		'color_scheme'                => array(
			'title'       => esc_html__( 'Color Scheme', 'baroque' ),
			'description' => '',
			'priority'    => 210,
			'capability'  => 'edit_theme_options',
			'panel'       => 'styling',
		),
		'theme_version'               => array(
			'title'       => esc_html__( 'Theme Version', 'baroque' ),
			'description' => '',
			'priority'    => 5,
			'capability'  => 'edit_theme_options',
			'panel'       => 'styling',
		),
		'page_layout'                 => array(
			'title'      => esc_html__( 'Page Layout', 'baroque' ),
			'priority'   => 10,
			'capability' => 'edit_theme_options',
			'panel'      => 'page',
		),
		'page_header'                 => array(
			'title'      => esc_html__( 'Page Header', 'baroque' ),
			'priority'   => 10,
			'capability' => 'edit_theme_options',
			'panel'      => 'page',
		),
		'not_found'                   => array(
			'title'      => esc_html__( '404 Page', 'baroque' ),
			'priority'   => 10,
			'capability' => 'edit_theme_options',
			'panel'      => 'page',
		),
		'coming_soon'                 => array(
			'title'      => esc_html__( 'Coming Soon Page', 'baroque' ),
			'priority'   => 10,
			'capability' => 'edit_theme_options',
			'panel'      => 'page',
		),
		'blog_page_header'            => array(
			'title'       => esc_html__( 'Blog Page Header', 'baroque' ),
			'description' => '',
			'priority'    => 10,
			'capability'  => 'edit_theme_options',
			'panel'       => 'blog',
		),
		'blog_page'                   => array(
			'title'       => esc_html__( 'Blog Page', 'baroque' ),
			'description' => '',
			'priority'    => 10,
			'capability'  => 'edit_theme_options',
			'panel'       => 'blog',
		),

		// Woocommerce
		'page_header_shop'            => array(
			'title'       => esc_html__( 'Catalog Page Header', 'baroque' ),
			'description' => '',
			'priority'    => 5,
			'capability'  => 'edit_theme_options',
			'panel'       => 'woocommerce',
		),
		'woocommerce_product_catalog' => array(
			'title'       => esc_html__( 'Product Catalog', 'baroque' ),
			'description' => '',
			'priority'    => 10,
			'panel'       => 'woocommerce',
			'capability'  => 'edit_theme_options',
		),
		'shop_badge'                  => array(
			'title'       => esc_html__( 'Badges', 'baroque' ),
			'description' => '',
			'priority'    => 40,
			'panel'       => 'woocommerce',
			'capability'  => 'edit_theme_options',
		),
		'single_product'              => array(
			'title'       => esc_html__( 'Single Product', 'baroque' ),
			'description' => '',
			'priority'    => 90,
			'panel'       => 'woocommerce',
			'capability'  => 'edit_theme_options',
		),

		'single_post'                 => array(
			'title'       => esc_html__( 'Single Post', 'baroque' ),
			'description' => '',
			'priority'    => 10,
			'capability'  => 'edit_theme_options',
			'panel'       => 'blog',
		),
		'portfolio_page_header'       => array(
			'title'       => esc_html__( 'Portfolio Page Header', 'baroque' ),
			'description' => '',
			'priority'    => 10,
			'capability'  => 'edit_theme_options',
			'panel'       => 'portfolio',
		),
		'portfolio_page'              => array(
			'title'       => esc_html__( 'Portfolio Page', 'baroque' ),
			'description' => '',
			'priority'    => 10,
			'capability'  => 'edit_theme_options',
			'panel'       => 'portfolio',
		),
		'single_portfolio'            => array(
			'title'       => esc_html__( 'Single Portfolio', 'baroque' ),
			'description' => '',
			'priority'    => 10,
			'capability'  => 'edit_theme_options',
			'panel'       => 'portfolio',
		),
		'single_portfolio_nav'            => array(
			'title'       => esc_html__( 'Single Portfolio Navigation', 'baroque' ),
			'description' => '',
			'priority'    => 10,
			'capability'  => 'edit_theme_options',
			'panel'       => 'portfolio',
		),
		'single_service_nav'            => array(
			'title'       => esc_html__( 'Single Service Navigation', 'baroque' ),
			'description' => '',
			'priority'    => 10,
			'capability'  => 'edit_theme_options',
			'panel'       => 'service',
		),
		'footer'                      => array(
			'title'       => esc_html__( 'Footer', 'baroque' ),
			'description' => '',
			'priority'    => 50,
			'capability'  => 'edit_theme_options',
		),
	);

	$fields = array(
		'image_sizes_default'              => array(
			'type'     => 'multicheck',
			'label'    => esc_html__( 'Image Sizes', 'baroque' ),
			'default'  => array(
				'blog_grid',
				'blog_classic',
				'blog_list',
				'blog_masonry',
				'portfolio_carousel',
				'portfolio_grid_wide',
				'portfolio_masonry',
				'portfolio_metro',
				'portfolio_single_2',
			),
			'section'  => 'image_sizes',
			'priority' => 20,
			'choices'  => array(
				'blog_grid'           => esc_html__( 'Blog Grid', 'baroque' ),
				'blog_classic'        => esc_html__( 'Blog Classic', 'baroque' ),
				'blog_list'           => esc_html__( 'Blog List', 'baroque' ),
				'blog_masonry'        => esc_html__( 'Blog Masonry', 'baroque' ),
				'portfolio_carousel'  => esc_html__( 'Portfolio Carousel', 'baroque' ),
				'portfolio_list'      => esc_html__( 'Portfolio List', 'baroque' ),
				'portfolio_grid_wide' => esc_html__( 'Portfolio Grid Wide', 'baroque' ),
				'portfolio_masonry'   => esc_html__( 'Portfolio Masonry', 'baroque' ),
				'portfolio_metro'     => esc_html__( 'Portfolio Metro', 'baroque' ),
				'portfolio_single_2'  => esc_html__( 'Single Portfolio style 2', 'baroque' ),
			),
		),
		// Theme Version
		'theme_version'                    => array(
			'type'        => 'radio',
			'label'       => esc_html__( 'Theme Version', 'baroque' ),
			'section'     => 'theme_version',
			'default'     => 'light',
			'priority'    => 10,
			'description' => esc_html__( 'Select default theme version.', 'baroque' ),
			'choices'     => array(
				'light' => esc_html__( 'Light', 'baroque' ),
				'dark'  => esc_html__( 'Dark', 'baroque' ),
			),
		),

		// Typography
		'font_families_typo'                        => array(
			'type'        => 'toggle',
			'label'       => esc_html__( 'Font Family Default', 'baroque' ),
			'section'     => 'font_families_typo',
			'default'     => true,
		),
		'body_typo'                        => array(
			'type'     => 'typography',
			'label'    => esc_html__( 'Body', 'baroque' ),
			'section'  => 'body_typo',
			'priority' => 10,
			'default'  => array(
				'font-family'    => 'Work Sans',
				'variant'        => '400',
				'font-size'      => '16px',
				'line-height'    => '1.6',
				'letter-spacing' => '0',
				'subsets'        => array( 'latin-ext' ),
				'color'          => '#666666',
				'text-transform' => 'none',
			),
		),
		'heading1_typo'                    => array(
			'type'     => 'typography',
			'label'    => esc_html__( 'Heading 1', 'baroque' ),
			'section'  => 'heading_typo',
			'priority' => 10,
			'default'  => array(
				'font-family'    => 'Work Sans',
				'variant'        => '600',
				'font-size'      => '36px',
				'line-height'    => '1.2',
				'letter-spacing' => '0',
				'subsets'        => array( 'latin-ext' ),
				'color'          => '#000000',
				'text-transform' => 'none',
			),
		),
		'heading2_typo'                    => array(
			'type'     => 'typography',
			'label'    => esc_html__( 'Heading 2', 'baroque' ),
			'section'  => 'heading_typo',
			'priority' => 10,
			'default'  => array(
				'font-family'    => 'Work Sans',
				'variant'        => '600',
				'font-size'      => '30px',
				'line-height'    => '1.2',
				'letter-spacing' => '0',
				'subsets'        => array( 'latin-ext' ),
				'color'          => '#000000',
				'text-transform' => 'none',
			),
		),
		'heading3_typo'                    => array(
			'type'     => 'typography',
			'label'    => esc_html__( 'Heading 3', 'baroque' ),
			'section'  => 'heading_typo',
			'priority' => 10,
			'default'  => array(
				'font-family'    => 'Work Sans',
				'variant'        => '600',
				'font-size'      => '24px',
				'line-height'    => '1.2',
				'letter-spacing' => '0',
				'subsets'        => array( 'latin-ext' ),
				'color'          => '#000000',
				'text-transform' => 'none',
			),
		),
		'heading4_typo'                    => array(
			'type'     => 'typography',
			'label'    => esc_html__( 'Heading 4', 'baroque' ),
			'section'  => 'heading_typo',
			'priority' => 10,
			'default'  => array(
				'font-family'    => 'Work Sans',
				'variant'        => '600',
				'font-size'      => '18px',
				'line-height'    => '1.2',
				'letter-spacing' => '0',
				'subsets'        => array( 'latin-ext' ),
				'color'          => '#000000',
				'text-transform' => 'none',
			),
		),
		'heading5_typo'                    => array(
			'type'     => 'typography',
			'label'    => esc_html__( 'Heading 5', 'baroque' ),
			'section'  => 'heading_typo',
			'priority' => 10,
			'default'  => array(
				'font-family'    => 'Work Sans',
				'variant'        => '600',
				'font-size'      => '16px',
				'line-height'    => '1.2',
				'letter-spacing' => '0',
				'subsets'        => array( 'latin-ext' ),
				'color'          => '#000000',
				'text-transform' => 'none',
			),
		),
		'heading6_typo'                    => array(
			'type'     => 'typography',
			'label'    => esc_html__( 'Heading 6', 'baroque' ),
			'section'  => 'heading_typo',
			'priority' => 10,
			'default'  => array(
				'font-family'    => 'Work Sans',
				'variant'        => '600',
				'font-size'      => '12px',
				'line-height'    => '1.2',
				'letter-spacing' => '0',
				'subsets'        => array( 'latin-ext' ),
				'color'          => '#000000',
				'text-transform' => 'none',
			),
		),
		'menu_typo'                        => array(
			'type'     => 'typography',
			'label'    => esc_html__( 'Menu', 'baroque' ),
			'section'  => 'header_typo',
			'priority' => 10,
			'default'  => array(
				'font-family'    => 'Work Sans',
				'variant'        => '600',
				'subsets'        => array( 'latin-ext' ),
				'font-size'      => '16px',
				'color'          => '#000',
				'text-transform' => 'none',
			),
		),
		'sub_menu_typo'                    => array(
			'type'     => 'typography',
			'label'    => esc_html__( 'Sub Menu', 'baroque' ),
			'section'  => 'header_typo',
			'priority' => 10,
			'default'  => array(
				'font-family'    => 'Work Sans',
				'variant'        => '400',
				'subsets'        => array( 'latin-ext' ),
				'font-size'      => '14px',
				'color'          => '#666666',
				'text-transform' => 'none',
			),
		),
		'footer_text_typo'                 => array(
			'type'     => 'typography',
			'label'    => esc_html__( 'Footer Text', 'baroque' ),
			'section'  => 'footer_typo',
			'priority' => 10,
			'default'  => array(
				'font-family' => 'Work Sans',
				'variant'     => '400',
				'subsets'     => array( 'latin-ext' ),
				'font-size'   => '16px',
			),
		),

		'menu_sidebar_typo'                        => array(
			'type'     => 'typography',
			'label'    => esc_html__( 'Menu Sidebar', 'baroque' ),
			'section'  => 'menu_sidebar_typo',
			'priority' => 10,
			'default'  => array(
				'font-family'    => 'Work Sans',
				'variant'        => '600',
				'subsets'        => array( 'latin-ext' ),
				'font-size'      => '36px',
				'color'          => '#999',
				'text-transform' => 'none',
			),
		),
		'sub_menu_sidebar_typo'                    => array(
			'type'     => 'typography',
			'label'    => esc_html__( 'Sub Menu Sidebar', 'baroque' ),
			'section'  => 'menu_sidebar_typo',
			'priority' => 10,
			'default'  => array(
				'font-family'    => 'Work Sans',
				'variant'        => '400',
				'subsets'        => array( 'latin-ext' ),
				'font-size'      => '18px',
				'color'          => '#999',
				'text-transform' => 'none',
			),
		),

		// Header layout
		'header_layout'                    => array(
			'type'     => 'select',
			'label'    => esc_html__( 'Header Layout', 'baroque' ),
			'section'  => 'header',
			'default'  => 'v1',
			'priority' => 10,
			'choices'  => array(
				'v1' => esc_html__( 'Header v1', 'baroque' ),
				'v2' => esc_html__( 'Header v2', 'baroque' ),
				'v3' => esc_html__( 'Header v3', 'baroque' ),
				'v4' => esc_html__( 'Header v4', 'baroque' ),
				'v5' => esc_html__( 'Header v5', 'baroque' ),
			),
		),

		'header_sticky'                    => array(
			'type'     => 'toggle',
			'label'    => esc_html__( 'Header Sticky', 'baroque' ),
			'default'  => 0,
			'section'  => 'header',
			'priority' => 10,
		),

		'header_transparent'               => array(
			'type'        => 'toggle',
			'label'       => esc_html__( 'Header Transparent', 'baroque' ),
			'default'     => 1,
			'section'     => 'header',
			'priority'    => 10,
			'description' => esc_html__( 'Check this to enable header transparent in homepage only.', 'baroque' ),
		),

		'sticky_header_background'         => array(
			'type'            => 'toggle',
			'label'           => esc_html__( 'Sticky Header Background', 'baroque' ),
			'default'         => 1,
			'section'         => 'header',
			'priority'        => 10,
			'description'     => esc_html__( 'Check this to enable background color for sticky header transparent in homepage only.', 'baroque' ),
			'active_callback' => array(
				array(
					'setting'  => 'header_sticky',
					'operator' => '==',
					'value'    => 1,
				),
				array(
					'setting'  => 'header_transparent',
					'operator' => '==',
					'value'    => 1,
				),
			),
		),

		'header_text_color'                => array(
			'type'        => 'radio',
			'label'       => esc_html__( 'Header Text Color', 'baroque' ),
			'description' => esc_html__( 'Text light apply for homepage only', 'baroque' ),
			'section'     => 'header',
			'default'     => 'dark',
			'choices'     => array(
				'dark'  => esc_html__( 'Dark', 'baroque' ),
				'light' => esc_html__( 'Light', 'baroque' ),
			),
		),

		'menu_extras'                      => array(
			'type'     => 'multicheck',
			'label'    => esc_html__( 'Menu Extras', 'baroque' ),
			'section'  => 'header',
			'default'  => array( 'cart', 'menu' ),
			'priority' => 10,
			'choices'  => array(
				'cart'     => esc_html__( 'Cart', 'baroque' ),
				'menu'     => esc_html__( 'Menu', 'baroque' ),
				'language' => esc_html__( 'Language', 'baroque' ),
			),
		),

		'menu_label'                       => array(
			'type'     => 'text',
			'label'    => esc_html__( 'Menu Label', 'baroque' ),
			'section'  => 'header',
			'default'  => esc_html__( 'MENU', 'baroque' ),
			'priority' => 10,
		),

		// Canvas Menu

		'canvas_menu_img'                  => array(
			'type'     => 'image',
			'label'    => esc_html__( 'Background Image', 'baroque' ),
			'section'  => 'canvas_menu',
			'default'  => '',
			'priority' => 10,
		),

		'header_menu_sidebar'              => array(
			'type'     => 'multicheck',
			'label'    => esc_html__( 'Menu Sidebar', 'baroque' ),
			'section'  => 'canvas_menu',
			'default'  => array( 'language', 'menu', 'socials', 'text' ),
			'priority' => 10,
			'choices'  => array(
				'language' => esc_html__( 'Language', 'baroque' ),
				'menu'     => esc_html__( 'Primary Menu', 'baroque' ),
				'socials'  => esc_html__( 'Socials', 'baroque' ),
				'text'     => esc_html__( 'Custom Text', 'baroque' ),
			),
		),
		'menu_sidebar_socials'             => array(
			'type'            => 'repeater',
			'label'           => esc_html__( 'Socials', 'baroque' ),
			'section'         => 'canvas_menu',
			'priority'        => 10,
			'row_label'       => array(
				'type'  => 'text',
				'value' => esc_attr__( 'Social', 'baroque' ),
			),
			'fields'          => array(
				'link_url' => array(
					'type'        => 'text',
					'label'       => esc_html__( 'Social URL', 'baroque' ),
					'description' => esc_html__( 'Enter the URL for this social', 'baroque' ),
					'default'     => '',
				),
			),
			'active_callback' => array(
				array(
					'setting'  => 'header_menu_sidebar',
					'operator' => 'contains',
					'value'    => 'socials',
				),
			),
		),
		'menu_sidebar_text'                => array(
			'type'            => 'textarea',
			'label'           => esc_html__( 'Custom Text', 'baroque' ),
			'section'         => 'canvas_menu',
			'default'         => '',
			'priority'        => 10,
			'active_callback' => array(
				array(
					'setting'  => 'header_menu_sidebar',
					'operator' => 'contains',
					'value'    => 'text',
				),
			),
		),

		// Logo
		'logo_type'                        => array(
			'type'    => 'radio',
			'label'   => esc_html__( 'Logo Type', 'baroque' ),
			'default' => 'image',
			'section' => 'logo',
			'choices' => array(
				'image' => esc_html__( 'Image', 'baroque' ),
				'svg'   => esc_html__( 'SVG', 'baroque' ),
			),
		),
		'logo'                             => array(
			'type'            => 'image',
			'label'           => esc_html__( 'Logo', 'baroque' ),
			'section'         => 'logo',
			'default'         => '',
			'priority'        => 10,
			'active_callback' => array(
				array(
					'setting'  => 'logo_type',
					'operator' => '==',
					'value'    => 'image',
				),
			),
		),
		'logo_light'                       => array(
			'type'            => 'image',
			'label'           => esc_html__( 'Logo Light', 'baroque' ),
			'section'         => 'logo',
			'default'         => '',
			'priority'        => 10,
			'active_callback' => array(
				array(
					'setting'  => 'logo_type',
					'operator' => '==',
					'value'    => 'image',
				),
			),
		),

		'logo_svg'                         => array(
			'type'            => 'textarea',
			'label'           => esc_html__( 'Logo SVG', 'baroque' ),
			'section'         => 'logo',
			'description'     => esc_html__( 'Paste SVG code of your logo here', 'baroque' ),
			'output'          => array(
				array(
					'element' => '.site-logo .logo',
				),
			),
			'active_callback' => array(
				array(
					'setting'  => 'logo_type',
					'operator' => '==',
					'value'    => 'svg',
				),
			),
		),
		'logo_svg_light'                   => array(
			'type'            => 'textarea',
			'label'           => esc_html__( 'Logo SVG Light', 'baroque' ),
			'section'         => 'logo',
			'description'     => esc_html__( 'Paste SVG code of your logo here', 'baroque' ),
			'output'          => array(
				array(
					'element' => '.site-logo .logo',
				),
			),
			'active_callback' => array(
				array(
					'setting'  => 'logo_type',
					'operator' => '==',
					'value'    => 'svg',
				),
			),
		),
		'logo_width'                       => array(
			'type'     => 'number',
			'label'    => esc_html__( 'Logo Width', 'baroque' ),
			'section'  => 'logo',
			'default'  => '',
			'priority' => 10,
		),
		'logo_height'                      => array(
			'type'     => 'number',
			'label'    => esc_html__( 'Logo Height', 'baroque' ),
			'section'  => 'logo',
			'default'  => '',
			'priority' => 10,
		),
		'logo_position'                    => array(
			'type'     => 'spacing',
			'label'    => esc_html__( 'Logo Margin', 'baroque' ),
			'section'  => 'logo',
			'priority' => 10,
			'default'  => array(
				'top'    => '0',
				'bottom' => '0',
				'left'   => '0',
				'right'  => '0',
			),
		),

		// Color Scheme
		'color_scheme'                     => array(
			'type'     => 'palette',
			'label'    => esc_html__( 'Base Color Scheme', 'baroque' ),
			'default'  => '#666600',
			'section'  => 'color_scheme',
			'priority' => 10,
			'choices'  => array(
				'#666600' => array( '#666600' ),
				'#ee4300' => array( '#ee4300' ),
			),
		),
		'custom_color_scheme'              => array(
			'type'     => 'toggle',
			'label'    => esc_html__( 'Custom Color Scheme', 'baroque' ),
			'default'  => 0,
			'section'  => 'color_scheme',
			'priority' => 10,
		),
		'custom_color'                     => array(
			'type'            => 'color',
			'label'           => esc_html__( 'Color', 'baroque' ),
			'default'         => '',
			'section'         => 'color_scheme',
			'priority'        => 10,
			'active_callback' => array(
				array(
					'setting'  => 'custom_color_scheme',
					'operator' => '==',
					'value'    => 1,
				),
			),
		),

		// Page
		'page_layout'                      => array(
			'type'        => 'select',
			'label'       => esc_html__( 'Page Layout', 'baroque' ),
			'section'     => 'page_layout',
			'default'     => 'full-content',
			'priority'    => 10,
			'description' => esc_html__( 'Select default sidebar for page default.', 'baroque' ),
			'choices'     => array(
				'full-content'    => esc_html__( 'Full Content', 'baroque' ),
				'sidebar-content' => esc_html__( 'Left Sidebar', 'baroque' ),
				'content-sidebar' => esc_html__( 'Right Sidebar', 'baroque' ),
			),
		),
		'page_page_header'                 => array(
			'type'        => 'toggle',
			'label'       => esc_html__( 'Page Header', 'baroque' ),
			'default'     => 1,
			'section'     => 'page_header',
			'priority'    => 10,
			'description' => esc_html__( 'Check this option to show the page header below the header.', 'baroque' ),
		),

		// 404
		'not_found_img'                    => array(
			'type'     => 'image',
			'label'    => esc_html__( 'Image', 'baroque' ),
			'section'  => 'not_found',
			'default'  => '',
			'priority' => 10,
		),

		// Coming Soon
		'coming_soon_logo'                 => array(
			'type'     => 'image',
			'label'    => esc_html__( 'Logo', 'baroque' ),
			'section'  => 'coming_soon',
			'default'  => '',
			'priority' => 10,
		),
		'coming_soon_background_image'     => array(
			'type'     => 'image',
			'label'    => esc_html__( 'Coming Soon Background Image', 'baroque' ),
			'section'  => 'coming_soon',
			'default'  => '',
			'priority' => 10,
		),
		'coming_soon_background_color'     => array(
			'type'     => 'color',
			'label'    => esc_html__( 'Coming Soon Background Color', 'baroque' ),
			'default'  => '',
			'section'  => 'coming_soon',
			'priority' => 10,
		),
		'show_coming_soon_socials'         => array(
			'type'        => 'toggle',
			'label'       => esc_html__( 'Show Socials', 'baroque' ),
			'section'     => 'coming_soon',
			'default'     => 1,
			'description' => esc_html__( 'Display social sharing icons on Coming Soon Page', 'baroque' ),
			'priority'    => 20,
		),
		'coming_soon_socials'              => array(
			'type'            => 'repeater',
			'label'           => esc_html__( 'Socials', 'baroque' ),
			'section'         => 'coming_soon',
			'priority'        => 60,
			'default'         => array(
				array(
					'link_url' => 'https://facebook.com/baroque',
				),
				array(
					'link_url' => 'https://twitter.com/baroque',
				),
				array(
					'link_url' => 'https://plus.google.com/baroque',
				),
				array(
					'link_url' => 'https://dribbble.com/',
				),
			),
			'fields'          => array(
				'link_url' => array(
					'type'        => 'text',
					'label'       => esc_html__( 'Social URL', 'baroque' ),
					'description' => esc_html__( 'Enter the URL for this social', 'baroque' ),
					'default'     => '',
				),
			),
			'active_callback' => array(
				array(
					'setting'  => 'show_coming_soon_socials',
					'operator' => '==',
					'value'    => 1,
				),
			),
		),

		// Blog
		'blog_page_header'                 => array(
			'type'        => 'toggle',
			'default'     => 1,
			'label'       => esc_html__( 'Enable Page Header', 'baroque' ),
			'section'     => 'blog_page_header',
			'description' => esc_html__( 'Enable to show a page header for blog page below the site header', 'baroque' ),
			'priority'    => 10,
		),
		'blog_page_header_title'           => array(
			'type'            => 'textarea',
			'label'           => esc_html__( 'Blog Page Header Title', 'baroque' ),
			'section'         => 'blog_page_header',
			'default'         => '',
			'priority'        => 10,
			'active_callback' => array(
				array(
					'setting'  => 'blog_page_header',
					'operator' => '==',
					'value'    => true,
				),
			),
		),
		'blog_description'                 => array(
			'type'            => 'textarea',
			'label'           => esc_html__( 'Blog Description', 'baroque' ),
			'description'     => esc_html__( 'Shortcodes are allowed', 'baroque' ),
			'section'         => 'blog_page_header',
			'default'         => '',
			'priority'        => 10,
			'active_callback' => array(
				array(
					'setting'  => 'blog_page_header',
					'operator' => '==',
					'value'    => true,
				),
			),
		),
		'blog_style'                       => array(
			'type'     => 'select',
			'label'    => esc_html__( 'Blog Style', 'baroque' ),
			'section'  => 'blog_page',
			'default'  => 'classic',
			'priority' => 10,
			'choices'  => array(
				'grid'    => esc_html__( 'Grid', 'baroque' ),
				'list'    => esc_html__( 'List', 'baroque' ),
				'masonry' => esc_html__( 'Masonry', 'baroque' ),
				'classic' => esc_html__( 'Classic', 'baroque' ),
				'text'    => esc_html__( 'Text', 'baroque' ),
			),
		),
		'blog_layout'                      => array(
			'type'            => 'select',
			'label'           => esc_html__( 'Blog Classic Layout', 'baroque' ),
			'section'         => 'blog_page',
			'default'         => 'content-sidebar',
			'priority'        => 10,
			'description'     => esc_html__( 'Select default sidebar for blog classic.', 'baroque' ),
			'choices'         => array(
				'content-sidebar' => esc_html__( 'Right Sidebar', 'baroque' ),
				'sidebar-content' => esc_html__( 'Left Sidebar', 'baroque' ),
				'full-content'    => esc_html__( 'Full Content', 'baroque' ),
			),
			'active_callback' => array(
				array(
					'setting'  => 'blog_style',
					'operator' => '==',
					'value'    => 'classic',
				),
			),
		),
		'blog_entry_meta'                  => array(
			'type'     => 'multicheck',
			'label'    => esc_html__( 'Entry Meta', 'baroque' ),
			'section'  => 'blog_page',
			'default'  => array( 'date', 'cat' ),
			'choices'  => array(
				'date' => esc_html__( 'Date', 'baroque' ),
				'cat'  => esc_html__( 'Categories', 'baroque' ),
			),
			'priority' => 10,
		),
		'excerpt_length'                   => array(
			'type'     => 'number',
			'label'    => esc_html__( 'Excerpt Length', 'baroque' ),
			'section'  => 'blog_page',
			'default'  => '20',
			'priority' => 10,
		),
		'blog_custom_field_1'              => array(
			'type'    => 'custom',
			'section' => 'blog_page',
			'default' => '<hr/>',
		),
		'blog_cat_filter'                  => array(
			'type'     => 'toggle',
			'default'  => 0,
			'label'    => esc_html__( 'Categories Filter', 'baroque' ),
			'section'  => 'blog_page',
			'priority' => 10,
		),
		'blog_categories_numbers'          => array(
			'type'            => 'number',
			'label'           => esc_html__( 'Categories Numbers', 'baroque' ),
			'section'         => 'blog_page',
			'default'         => '5',
			'priority'        => 10,
			'active_callback' => array(
				array(
					'setting'  => 'blog_cat_filter',
					'operator' => '==',
					'value'    => true,
				),
			),
		),
		'blog_categories'                  => array(
			'type'            => 'textarea',
			'label'           => esc_html__( 'Categories slug', 'baroque' ),
			'section'         => 'blog_page',
			'default'         => '',
			'priority'        => 10,
			'description'     => esc_html__( 'Enter categories slug you want to display. Each slug is separated by comma character ",". If empty, it will display default', 'baroque' ),
			'active_callback' => array(
				array(
					'setting'  => 'blog_cat_filter',
					'operator' => '==',
					'value'    => 1,
				),
			),
		),
		'blog_custom_field_2'              => array(
			'type'    => 'custom',
			'section' => 'blog_page',
			'default' => '<hr/>',
		),
		'type_nav'                         => array(
			'type'     => 'select',
			'label'    => esc_html__( 'Type of Navigation', 'baroque' ),
			'section'  => 'blog_page',
			'default'  => 'numeric',
			'priority' => 10,
			'choices'  => array(
				'numeric'   => esc_html__( 'Numeric', 'baroque' ),
				'link'      => esc_html__( 'Link', 'baroque' ),
				'view_more' => esc_html__( 'View More', 'baroque' ),
			),
		),
		'view_more_text'                   => array(
			'type'            => 'text',
			'label'           => esc_html__( 'View More Text', 'baroque' ),
			'section'         => 'blog_page',
			'default'         => esc_html__( 'MORE', 'baroque' ),
			'priority'        => 10,
			'active_callback' => array(
				array(
					'setting'  => 'type_nav',
					'operator' => '==',
					'value'    => 'view_more',
				),
			),
		),
		'view_more_style'                  => array(
			'type'            => 'select',
			'label'           => esc_html__( 'Style', 'baroque' ),
			'section'         => 'blog_page',
			'default'         => '1',
			'priority'        => 10,
			'choices'         => array(
				'1' => esc_html__( 'Style 1', 'baroque' ),
				'2' => esc_html__( 'Style 2', 'baroque' ),
			),
			'active_callback' => array(
				array(
					'setting'  => 'type_nav',
					'operator' => '==',
					'value'    => 'view_more',
				),
			),
		),

		// Single Posts
		'single_post_layout'               => array(
			'type'        => 'select',
			'label'       => esc_html__( 'Single Post Layout', 'baroque' ),
			'section'     => 'single_post',
			'default'     => 'full-content',
			'priority'    => 5,
			'description' => esc_html__( 'Select default sidebar for the single post page.', 'baroque' ),
			'choices'     => array(
				'content-sidebar' => esc_html__( 'Right Sidebar', 'baroque' ),
				'sidebar-content' => esc_html__( 'Left Sidebar', 'baroque' ),
				'full-content'    => esc_html__( 'Full Content', 'baroque' ),
			),
		),
		'show_post_format'                 => array(
			'type'        => 'toggle',
			'label'       => esc_html__( 'Show Post Format', 'baroque' ),
			'description' => esc_html__( 'Check this option to show post format in the single post page.', 'baroque' ),
			'section'     => 'single_post',
			'default'     => 1,
			'priority'    => 10,
		),
		'post_entry_meta'                  => array(
			'type'     => 'multicheck',
			'label'    => esc_html__( 'Entry Meta', 'baroque' ),
			'section'  => 'single_post',
			'default'  => array( 'date', 'cat' ),
			'choices'  => array(
				'date' => esc_html__( 'Date', 'baroque' ),
				'cat'  => esc_html__( 'Categories', 'baroque' ),
			),
			'priority' => 10,
		),
		'post_custom_field_1'              => array(
			'type'    => 'custom',
			'section' => 'single_post',
			'default' => '<hr/>',
		),

		'show_post_social_share'           => array(
			'type'        => 'toggle',
			'label'       => esc_html__( 'Show Socials Share', 'baroque' ),
			'description' => esc_html__( 'Check this option to show socials share in the single post page.', 'baroque' ),
			'section'     => 'single_post',
			'default'     => 0,
			'priority'    => 10,
		),

		'post_socials_share'               => array(
			'type'            => 'multicheck',
			'label'           => esc_html__( 'Socials Share', 'baroque' ),
			'section'         => 'single_post',
			'default'         => array( 'facebook', 'twitter', 'google', 'tumblr' ),
			'choices'         => array(
				'facebook'  => esc_html__( 'Facebook', 'baroque' ),
				'twitter'   => esc_html__( 'Twitter', 'baroque' ),
				'google'    => esc_html__( 'Google Plus', 'baroque' ),
				'tumblr'    => esc_html__( 'Tumblr', 'baroque' ),
				'pinterest' => esc_html__( 'Pinterest', 'baroque' ),
				'linkedin'  => esc_html__( 'Linkedin', 'baroque' ),
			),
			'priority'        => 10,
			'active_callback' => array(
				array(
					'setting'  => 'show_post_social_share',
					'operator' => '==',
					'value'    => 1,
				),
			),
		),
		'show_author_box'                  => array(
			'type'     => 'toggle',
			'label'    => esc_html__( 'Show Author Box', 'baroque' ),
			'section'  => 'single_post',
			'default'  => 0,
			'priority' => 10,
		),
		'post_custom_field_2'              => array(
			'type'    => 'custom',
			'section' => 'single_post',
			'default' => '<hr/>',
		),
		'single_post_col'                  => array(
			'type'        => 'slider',
			'label'       => esc_html__( 'Single Post Columns', 'baroque' ),
			'description' => esc_html__( 'Set Columns for Header Section, Footer Section and Comment area of Single Post', 'baroque' ),
			'section'     => 'single_post',
			'transport'   => 'auto',
			'default'     => 12,
			'choices'     => array(
				'min'  => '1',
				'max'  => '12',
				'step' => '1',
			),
		),
		'single_post_col_offset'           => array(
			'type'        => 'slider',
			'label'       => esc_html__( 'Single Post Offset Columns', 'baroque' ),
			'description' => esc_html__( 'Increase the left margin of Header Section, Footer Section and Comment area in Single Post by number columns', 'baroque' ),
			'section'     => 'single_post',
			'transport'   => 'auto',
			'default'     => 0,
			'choices'     => array(
				'min'  => '0',
				'max'  => '11',
				'step' => '1',
			),
		),
		'post_custom_field_3'              => array(
			'type'    => 'custom',
			'section' => 'single_post',
			'default' => '<hr/>',
		),
		'related_posts'                    => array(
			'type'        => 'toggle',
			'label'       => esc_html__( 'Related Posts', 'baroque' ),
			'section'     => 'single_post',
			'description' => esc_html__( 'Check this option to show related posts in the single post page.', 'baroque' ),
			'default'     => 0,
			'priority'    => 20,
		),
		'related_posts_title'              => array(
			'type'            => 'text',
			'label'           => esc_html__( 'Related Posts Title', 'baroque' ),
			'section'         => 'single_post',
			'default'         => esc_html__( 'POSTS YOU\'D MIGHT LIKE', 'baroque' ),
			'priority'        => 20,

			'active_callback' => array(
				array(
					'setting'  => 'related_post',
					'operator' => '==',
					'value'    => true,
				),
			),
		),
		'related_posts_numbers'            => array(
			'type'            => 'number',
			'label'           => esc_html__( 'Related Posts Numbers', 'baroque' ),
			'section'         => 'single_post',
			'default'         => '2',
			'priority'        => 20,
			'active_callback' => array(
				array(
					'setting'  => 'related_post',
					'operator' => '==',
					'value'    => true,
				),
			),
		),

		// Woocommerce
		'page_header_shop'                 => array(
			'type'        => 'toggle',
			'default'     => 1,
			'label'       => esc_html__( 'Enable Page Header', 'baroque' ),
			'section'     => 'page_header_shop',
			'description' => esc_html__( 'Enable to show a page header for catalog page below the site header', 'baroque' ),
			'priority'    => 10,
		),
		'catalog_page_header_image'        => array(
			'type'            => 'image',
			'label'           => esc_html__( 'Catalog Page Header Image', 'baroque' ),
			'section'         => 'page_header_shop',
			'default'         => '',
			'priority'        => 10,
			'active_callback' => array(
				array(
					'setting'  => 'page_header_shop',
					'operator' => '==',
					'value'    => true,
				),
			),
		),
		'catalog_page_title'               => array(
			'type'            => 'textarea',
			'label'           => esc_html__( 'Catalog Page Title', 'baroque' ),
			'section'         => 'page_header_shop',
			'default'         => esc_html__( 'Baroque Store', 'baroque' ),
			'priority'        => 10,
			'active_callback' => array(
				array(
					'setting'  => 'page_header_shop',
					'operator' => '==',
					'value'    => true,
				),
			),
		),
		'catalog_description'              => array(
			'type'            => 'textarea',
			'label'           => esc_html__( 'Catalog Description', 'baroque' ),
			'description'     => esc_html__( 'Shortcodes are allowed', 'baroque' ),
			'section'         => 'page_header_shop',
			'default'         => '',
			'priority'        => 10,
			'active_callback' => array(
				array(
					'setting'  => 'page_header_shop',
					'operator' => '==',
					'value'    => true,
				),
			),
		),

		'catalog_layout'                   => array(
			'type'        => 'select',
			'label'       => esc_html__( 'Catalog Layout', 'baroque' ),
			'default'     => 'full-content',
			'section'     => 'woocommerce_product_catalog',
			'priority'    => 70,
			'description' => esc_html__( 'Select default layout for catalog.', 'baroque' ),
			'choices'     => array(
				'sidebar-content' => esc_html__( 'Left Sidebar', 'baroque' ),
				'content-sidebar' => esc_html__( 'Right Sidebar', 'baroque' ),
				'full-content'    => esc_html__( 'Full Content', 'baroque' ),
			),
		),
		'disable_secondary_thumb'          => array(
			'type'        => 'toggle',
			'label'       => esc_html__( 'Disable Secondary Product Thumbnail', 'baroque' ),
			'section'     => 'woocommerce_product_catalog',
			'default'     => 0,
			'priority'    => 70,
			'description' => esc_html__( 'Check this option to disable secondary product thumbnail when hover over the main product image.', 'baroque' ),
		),
		'shop_toolbar_els1'                => array(
			'type'            => 'multicheck',
			'label'           => esc_html__( 'ToolBar Elements', 'baroque' ),
			'section'         => 'woocommerce_product_catalog',
			'default'         => array( 'cat', 'result', 'sort_by' ),
			'priority'        => 70,
			'choices'         => array(
				'result'  => esc_html__( 'Result Count', 'baroque' ),
				'sort_by' => esc_html__( 'Sort By', 'baroque' ),
				'cat'     => esc_html__( 'Categories', 'baroque' ),
			),
			'description'     => esc_html__( 'Select which elements you want to show.', 'baroque' ),
			'active_callback' => array(
				array(
					'setting'  => 'catalog_layout',
					'operator' => 'in',
					'value'    => array( 'full-content', 'sidebar-content', 'content-sidebar' ),
				),
			),
		),
		'catalog_custom_field_9'           => array(
			'type'     => 'custom',
			'section'  => 'woocommerce_product_catalog',
			'default'  => '<hr/>',
			'priority' => 70,
		),
		'catalog_categories_numbers'       => array(
			'type'     => 'number',
			'label'    => esc_html__( 'Categories Numbers', 'baroque' ),
			'section'  => 'woocommerce_product_catalog',
			'default'  => '5',
			'priority' => 70,
		),
		'catalog_categories'               => array(
			'type'        => 'textarea',
			'label'       => esc_html__( 'Categories slug', 'baroque' ),
			'section'     => 'woocommerce_product_catalog',
			'default'     => '',
			'priority'    => 70,
			'description' => esc_html__( 'Enter categories slug you want to display. Each slug is separated by comma character ",". If empty, it will display default', 'baroque' ),
		),
		'catalog_custom_field_10'          => array(
			'type'     => 'custom',
			'section'  => 'woocommerce_product_catalog',
			'default'  => '<hr/>',
			'priority' => 70,
		),
		'shop_nav_type'                    => array(
			'type'     => 'select',
			'label'    => esc_html__( 'Type of Navigation', 'baroque' ),
			'section'  => 'woocommerce_product_catalog',
			'default'  => 'numbers',
			'priority' => 90,
			'choices'  => array(
				'numbers'  => esc_html__( 'Page Numbers', 'baroque' ),
				'infinite' => esc_html__( 'Infinite Scroll', 'baroque' ),
			),
		),

		//Badge
		'show_badges'                      => array(
			'type'        => 'toggle',
			'label'       => esc_html__( 'Show Badges', 'baroque' ),
			'section'     => 'shop_badge',
			'default'     => 1,
			'priority'    => 20,
			'description' => esc_html__( 'Check this to show badges on every products.', 'baroque' ),
		),
		'badges'                           => array(
			'type'            => 'multicheck',
			'label'           => esc_html__( 'Badges', 'baroque' ),
			'section'         => 'shop_badge',
			'default'         => array( 'hot', 'new', 'sale', 'outofstock' ),
			'priority'        => 20,
			'choices'         => array(
				'hot'        => esc_html__( 'Hot', 'baroque' ),
				'new'        => esc_html__( 'New', 'baroque' ),
				'sale'       => esc_html__( 'Sale', 'baroque' ),
				'outofstock' => esc_html__( 'Out Of Stock', 'baroque' ),
			),
			'description'     => esc_html__( 'Select which badges you want to show', 'baroque' ),
			'active_callback' => array(
				array(
					'setting'  => 'show_badges',
					'operator' => '==',
					'value'    => 1,
				),
			),
		),
		'sale_text'                        => array(
			'type'            => 'text',
			'label'           => esc_html__( 'Custom Sale Text', 'baroque' ),
			'section'         => 'shop_badge',
			'default'         => 'Sale',
			'priority'        => 20,
			'active_callback' => array(
				array(
					'setting'  => 'show_badges',
					'operator' => '==',
					'value'    => 1,
				),
				array(
					'setting'  => 'badges',
					'operator' => 'contains',
					'value'    => 'sale',
				),
			),
		),
		'hot_text'                         => array(
			'type'            => 'text',
			'label'           => esc_html__( 'Custom Hot Text', 'baroque' ),
			'section'         => 'shop_badge',
			'default'         => 'Hot',
			'priority'        => 20,
			'active_callback' => array(
				array(
					'setting'  => 'show_badges',
					'operator' => '==',
					'value'    => 1,
				),
				array(
					'setting'  => 'badges',
					'operator' => 'contains',
					'value'    => 'hot',
				),
			),
		),
		'outofstock_text'                  => array(
			'type'            => 'text',
			'label'           => esc_html__( 'Custom Out Of Stock Text', 'baroque' ),
			'section'         => 'shop_badge',
			'default'         => 'Out Of Stock',
			'priority'        => 20,
			'active_callback' => array(
				array(
					'setting'  => 'show_badges',
					'operator' => '==',
					'value'    => 1,
				),
				array(
					'setting'  => 'badges',
					'operator' => 'contains',
					'value'    => 'outofstock',
				),
			),
		),
		'new_text'                         => array(
			'type'            => 'text',
			'label'           => esc_html__( 'Custom New Text', 'baroque' ),
			'section'         => 'shop_badge',
			'default'         => 'New',
			'priority'        => 20,
			'active_callback' => array(
				array(
					'setting'  => 'show_badges',
					'operator' => '==',
					'value'    => 1,
				),
				array(
					'setting'  => 'badges',
					'operator' => 'contains',
					'value'    => 'new',
				),
			),
		),
		'product_newness'                  => array(
			'type'            => 'number',
			'label'           => esc_html__( 'Product Newness', 'baroque' ),
			'section'         => 'shop_badge',
			'default'         => 3,
			'priority'        => 20,
			'description'     => esc_html__( 'Display the "New" badge for how many days?', 'baroque' ),
			'active_callback' => array(
				array(
					'setting'  => 'show_badges',
					'operator' => '==',
					'value'    => 1,
				),
				array(
					'setting'  => 'badges',
					'operator' => 'contains',
					'value'    => 'new',
				),
			),
		),
		// Single Product
		'show_product_socials'             => array(
			'type'     => 'toggle',
			'label'    => esc_html__( 'Show Product Socials', 'baroque' ),
			'section'  => 'single_product',
			'default'  => 1,
			'priority' => 10,
		),
		'single_product_socials_share'     => array(
			'type'            => 'multicheck',
			'label'           => esc_html__( 'Socials Share', 'baroque' ),
			'section'         => 'single_product',
			'default'         => array( 'facebook', 'twitter', 'pinterest' ),
			'choices'         => array(
				'facebook'  => esc_html__( 'Facebook', 'baroque' ),
				'twitter'   => esc_html__( 'Twitter', 'baroque' ),
				'google'    => esc_html__( 'Google Plus', 'baroque' ),
				'tumblr'    => esc_html__( 'Tumblr', 'baroque' ),
				'pinterest' => esc_html__( 'Pinterest', 'baroque' ),
				'linkedin'  => esc_html__( 'Linkedin', 'baroque' ),
			),
			'priority'        => 10,
			'active_callback' => array(
				array(
					'setting'  => 'show_product_socials',
					'operator' => '==',
					'value'    => 1,
				),
			),
		),
		'show_product_meta'                => array(
			'type'        => 'multicheck',
			'label'       => esc_html__( 'Show Product Meta', 'baroque' ),
			'section'     => 'single_product',
			'default'     => array( 'sku', 'categories', 'tags' ),
			'priority'    => 40,
			'choices'     => array(
				'sku'        => esc_html__( 'SKU', 'baroque' ),
				'categories' => esc_html__( 'Categories', 'baroque' ),
				'tags'       => esc_html__( 'Tags', 'baroque' ),
			),
			'description' => esc_html__( 'Select which product meta you want to show in single product page', 'baroque' ),
		),
		'product_upsells'                  => array(
			'type'     => 'toggle',
			'label'    => esc_html__( 'Show Up-sells Products', 'baroque' ),
			'section'  => 'single_product',
			'default'  => 1,
			'priority' => 40,
		),
		'upsells_products_columns'         => array(
			'type'        => 'select',
			'label'       => esc_html__( 'Up-sells Products Columns', 'baroque' ),
			'section'     => 'single_product',
			'default'     => '4',
			'priority'    => 40,
			'description' => esc_html__( 'Specify how many columns of up-sells products you want to show on single product page', 'baroque' ),
			'choices'     => array(
				'4' => esc_html__( '4 Columns', 'baroque' ),
				'3' => esc_html__( '3 Columns', 'baroque' ),
				'5' => esc_html__( '5 Columns', 'baroque' ),
				'6' => esc_html__( '6 Columns', 'baroque' ),
			),
		),
		'upsells_products_numbers'         => array(
			'type'        => 'number',
			'label'       => esc_html__( 'Up-sells Products Numbers', 'baroque' ),
			'section'     => 'single_product',
			'default'     => 6,
			'priority'    => 40,
			'description' => esc_html__( 'Specify how many numbers of up-sells products you want to show on single product page', 'baroque' ),
		),
		'product_related'                  => array(
			'type'     => 'toggle',
			'label'    => esc_html__( 'Show Related Products', 'baroque' ),
			'section'  => 'single_product',
			'default'  => 1,
			'priority' => 40,
		),
		'related_products_columns'         => array(
			'type'        => 'select',
			'label'       => esc_html__( 'Related Products Columns', 'baroque' ),
			'section'     => 'single_product',
			'default'     => '4',
			'priority'    => 40,
			'description' => esc_html__( 'Specify how many columns of related products you want to show on single product page', 'baroque' ),
			'choices'     => array(
				'4' => esc_html__( '4 Columns', 'baroque' ),
				'3' => esc_html__( '3 Columns', 'baroque' ),
				'5' => esc_html__( '5 Columns', 'baroque' ),
				'6' => esc_html__( '6 Columns', 'baroque' ),
			),
		),
		'related_products_numbers'         => array(
			'type'        => 'number',
			'label'       => esc_html__( 'Related Products Numbers', 'baroque' ),
			'section'     => 'single_product',
			'default'     => 6,
			'priority'    => 40,
			'description' => esc_html__( 'Specify how many numbers of related products you want to show on single product page', 'baroque' ),
		),

		// Portfolio
		'portfolio_page_header'            => array(
			'type'        => 'toggle',
			'default'     => 1,
			'label'       => esc_html__( 'Enable Page Header', 'baroque' ),
			'section'     => 'portfolio_page_header',
			'description' => esc_html__( 'Enable to show a page header for portfolio page below the site header', 'baroque' ),
			'priority'    => 10,
		),
		'portfolio_page_header_title'      => array(
			'type'            => 'textarea',
			'label'           => esc_html__( 'Portfolio Page Header Title', 'baroque' ),
			'section'         => 'portfolio_page_header',
			'default'         => '',
			'priority'        => 10,
			'active_callback' => array(
				array(
					'setting'  => 'portfolio_page_header',
					'operator' => '==',
					'value'    => true,
				),
			),
		),
		'portfolio_style'                  => array(
			'type'        => 'select',
			'label'       => esc_html__( 'Portfolio Style', 'baroque' ),
			'section'     => 'portfolio_page',
			'default'     => 'grid',
			'priority'    => 10,
			'description' => esc_html__( 'Select style for portfolio page.', 'baroque' ),
			'choices'     => array(
				'grid'      => esc_html__( 'Grid Standard', 'baroque' ),
				'grid-wide' => esc_html__( 'Grid Wide', 'baroque' ),
				'list'      => esc_html__( 'List', 'baroque' ),
				'masonry'   => esc_html__( 'Masonry', 'baroque' ),
				'carousel'  => esc_html__( 'Slides', 'baroque' ),
				'metro'     => esc_html__( 'Metro', 'baroque' ),
				'parallax'  => esc_html__( 'Parallax', 'baroque' ),
			),
		),
		'portfolio_content_button'         => array(
			'type'            => 'text',
			'label'           => esc_html__( 'Button Text', 'baroque' ),
			'section'         => 'portfolio_page',
			'default'         => esc_html__( 'MORE', 'baroque' ),
			'priority'        => 10,
			'description'     => esc_html__( 'Enter button text', 'baroque' ),
			'active_callback' => array(
				array(
					'setting'  => 'portfolio_style',
					'operator' => 'in',
					'value'    => array( 'grid', 'list', 'parallax' ),
				),
			),
		),
		'portfolio_type_nav'               => array(
			'type'            => 'select',
			'label'           => esc_html__( 'Type of Navigation', 'baroque' ),
			'section'         => 'portfolio_page',
			'default'         => 'numeric',
			'priority'        => 10,
			'choices'         => array(
				'numeric'   => esc_html__( 'Numeric', 'baroque' ),
				'view_more' => esc_html__( 'View More', 'baroque' ),
			),
			'active_callback' => array(
				array(
					'setting'  => 'portfolio_style',
					'operator' => 'in',
					'value'    => array( 'grid', 'grid-wide', 'list', 'masonry', 'metro' ),
				),
			),
		),
		'portfolio_carousel_arrows'        => array(
			'type'            => 'toggle',
			'label'           => esc_html__( 'Portfolio Arrows', 'baroque' ),
			'default'         => 1,
			'section'         => 'portfolio_page',
			'priority'        => 10,
			'description'     => esc_html__( 'Check this option to show the arrows.', 'baroque' ),
			'active_callback' => array(
				array(
					'setting'  => 'portfolio_style',
					'operator' => '==',
					'value'    => 'carousel',
				),
			),
		),
		'portfolio_carousel_scrollbar'     => array(
			'type'            => 'toggle',
			'label'           => esc_html__( 'Portfolio Scrollbar', 'baroque' ),
			'default'         => 1,
			'section'         => 'portfolio_page',
			'priority'        => 10,
			'description'     => esc_html__( 'Check this option to show the scrollbar.', 'baroque' ),
			'active_callback' => array(
				array(
					'setting'  => 'portfolio_style',
					'operator' => '==',
					'value'    => 'carousel',
				),
			),
		),
		'portfolio_carousel_dots'          => array(
			'type'            => 'toggle',
			'label'           => esc_html__( 'Portfolio Dots', 'baroque' ),
			'default'         => 0,
			'section'         => 'portfolio_page',
			'priority'        => 10,
			'description'     => esc_html__( 'Check this option to show the dots.', 'baroque' ),
			'active_callback' => array(
				array(
					'setting'  => 'portfolio_style',
					'operator' => '==',
					'value'    => 'carousel',
				),
			),
		),
		'portfolio_cat_filter'             => array(
			'type'            => 'toggle',
			'default'         => 1,
			'label'           => esc_html__( 'Categories Filter', 'baroque' ),
			'section'         => 'portfolio_page',
			'priority'        => 10,
			'active_callback' => array(
				array(
					'setting'  => 'portfolio_style',
					'operator' => 'in',
					'value'    => array( 'grid', 'grid-wide', 'list', 'masonry', 'metro' ),
				),
			),
		),
		'portfolio_categories_numbers'     => array(
			'type'            => 'number',
			'label'           => esc_html__( 'Categories Numbers', 'baroque' ),
			'section'         => 'portfolio_page',
			'default'         => '5',
			'priority'        => 10,
			'active_callback' => array(
				array(
					'setting'  => 'portfolio_cat_filter',
					'operator' => '==',
					'value'    => true,
				),
			),
		),
		'portfolio_categories'             => array(
			'type'            => 'textarea',
			'label'           => esc_html__( 'Categories slug', 'baroque' ),
			'section'         => 'portfolio_page',
			'default'         => '',
			'priority'        => 10,
			'description'     => esc_html__( 'Enter categories slug you want to display. Each slug is separated by comma character ",". If empty, it will display default', 'baroque' ),
			'active_callback' => array(
				array(
					'setting'  => 'portfolio_cat_filter',
					'operator' => '==',
					'value'    => 1,
				),
			),
		),
		// Single Portfolio
		'single_portfolio_layout'          => array(
			'type'        => 'select',
			'label'       => esc_html__( 'Single Portfolio Layout', 'baroque' ),
			'section'     => 'single_portfolio',
			'default'     => '1',
			'priority'    => 10,
			'description' => esc_html__( 'Select default layout for the single portfolio.', 'baroque' ),
			'choices'     => array(
				'1' => esc_html__( 'Layout 1', 'baroque' ),
				'2' => esc_html__( 'Layout 2', 'baroque' ),
				'3' => esc_html__( 'Layout 3', 'baroque' ),
				'4' => esc_html__( 'Layout 4', 'baroque' ),
			),
		),
		'single_portfolio_meta'            => array(
			'type'        => 'toggle',
			'label'       => esc_html__( 'Single Portfolio Meta', 'baroque' ),
			'section'     => 'single_portfolio',
			'description' => esc_html__( 'Check this option to show meta in the single portfolio.', 'baroque' ),
			'default'     => 1,
			'priority'    => 10,
		),
		'single_portfolio_client_text'     => array(
			'type'     => 'text',
			'label'    => esc_html__( 'Client Text', 'baroque' ),
			'section'  => 'single_portfolio',
			'default'  => esc_html__( 'CLIENT', 'baroque' ),
			'priority' => 10,
		),
		'single_portfolio_location_text'   => array(
			'type'     => 'text',
			'label'    => esc_html__( 'Location Text', 'baroque' ),
			'section'  => 'single_portfolio',
			'default'  => esc_html__( 'LOCATION', 'baroque' ),
			'priority' => 10,
		),
		'single_portfolio_completion_text' => array(
			'type'     => 'text',
			'label'    => esc_html__( 'Completion Text', 'baroque' ),
			'section'  => 'single_portfolio',
			'default'  => esc_html__( 'COMPLETION', 'baroque' ),
			'priority' => 10,
		),
		'single_portfolio_area_text'       => array(
			'type'     => 'text',
			'label'    => esc_html__( 'Area Text', 'baroque' ),
			'section'  => 'single_portfolio',
			'default'  => esc_html__( 'AREA', 'baroque' ),
			'priority' => 10,
		),
		'single_portfolio_copyright'       => array(
			'type'            => 'textarea',
			'label'           => esc_html__( 'Copyright', 'baroque' ),
			'section'         => 'single_portfolio',
			'default'         => esc_html__( '&copy; BAROQUE 2017. DESIGNED BY LOGANCEE', 'baroque' ),
			'priority'        => 10,
			'active_callback' => array(
				array(
					'setting'  => 'single_portfolio_layout',
					'operator' => '==',
					'value'    => '3',
				),
			),
		),
		'show_portfolio_social_share'      => array(
			'type'        => 'toggle',
			'label'       => esc_html__( 'Show Socials Share', 'baroque' ),
			'description' => esc_html__( 'Check this option to show socials share in the single portfolio.', 'baroque' ),
			'section'     => 'single_portfolio',
			'default'     => 1,
			'priority'    => 10,
		),

		'single_portfolio_socials_share'   => array(
			'type'            => 'multicheck',
			'label'           => esc_html__( 'Socials Share', 'baroque' ),
			'section'         => 'single_portfolio',
			'default'         => array( 'facebook', 'twitter', 'google', 'tumblr' ),
			'choices'         => array(
				'facebook'  => esc_html__( 'Facebook', 'baroque' ),
				'twitter'   => esc_html__( 'Twitter', 'baroque' ),
				'google'    => esc_html__( 'Google Plus', 'baroque' ),
				'tumblr'    => esc_html__( 'Tumblr', 'baroque' ),
				'pinterest' => esc_html__( 'Pinterest', 'baroque' ),
				'linkedin'  => esc_html__( 'Linkedin', 'baroque' ),
			),
			'priority'        => 10,
			'active_callback' => array(
				array(
					'setting'  => 'show_portfolio_social_share',
					'operator' => '==',
					'value'    => 1,
				),
			),
		),

		// Portfolio Navigation
		'single_portfolio_nav_url' => array(
			'type'     => 'text',
			'label'    => esc_html__( 'URL', 'baroque' ),
			'section'  => 'single_portfolio_nav',
			'default'  => '',
			'priority' => 10,
		),
		'single_portfolio_nav_text'       => array(
			'type'     => 'text',
			'label'    => esc_html__( 'Text', 'baroque' ),
			'section'  => 'single_portfolio_nav',
			'default'  => '',
			'priority' => 10,
		),

		// Service Navigation
		'single_service_nav_url' => array(
			'type'     => 'text',
			'label'    => esc_html__( 'URL', 'baroque' ),
			'section'  => 'single_service_nav',
			'default'  => '',
			'priority' => 10,
		),
		'single_service_nav_text'       => array(
			'type'     => 'text',
			'label'    => esc_html__( 'Text', 'baroque' ),
			'section'  => 'single_service_nav',
			'default'  => '',
			'priority' => 10,
		),

		// Footer
		'back_to_top'                      => array(
			'type'     => 'toggle',
			'label'    => esc_html__( 'Back to Top', 'baroque' ),
			'section'  => 'footer',
			'default'  => 1,
			'priority' => 10,
		),
		'back_to_top_style'                => array(
			'type'        => 'select',
			'label'       => esc_html__( 'Style', 'baroque' ),
			'section'     => 'footer',
			'default'     => '1',
			'priority'    => 10,
			'choices'     => array(
				'1' => esc_html__( 'Style 1', 'baroque' ),
				'2' => esc_html__( 'Style 2', 'baroque' ),
			),
			'description' => esc_html__( 'Select Style for Back to Top Button', 'baroque' ),
		),
		'footer_custom_0'                  => array(
			'type'     => 'custom',
			'section'  => 'footer',
			'default'  => '<hr/>',
			'priority' => 10,
		),
		'preloader'                        => array(
			'type'     => 'toggle',
			'label'    => esc_html__( 'Preloader', 'baroque' ),
			'section'  => 'footer',
			'default'  => 1,
			'priority' => 10,
		),
		'footer_custom_1'                  => array(
			'type'     => 'custom',
			'section'  => 'footer',
			'default'  => '<hr/>',
			'priority' => 10,
		),
		'footer_layout'                    => array(
			'type'     => 'select',
			'label'    => esc_html__( 'Footer Layout', 'baroque' ),
			'section'  => 'footer',
			'default'  => '4',
			'priority' => 10,
			'choices'  => array(
				'1' => esc_html__( 'Layout 1', 'baroque' ),
				'2' => esc_html__( 'Layout 2', 'baroque' ),
				'3' => esc_html__( 'Layout 3 ( Transparent )', 'baroque' ),
				'4' => esc_html__( 'Layout 4', 'baroque' ),
			),
		),
		'footer_fixed'                     => array(
			'type'            => 'toggle',
			'label'           => esc_html__( 'Footer Fixed', 'baroque' ),
			'section'         => 'footer',
			'default'         => 1,
			'priority'        => 10,
			'active_callback' => array(
				array(
					'setting'  => 'footer_layout',
					'operator' => 'in',
					'value'    => array( '1', '2' ),
				),
			),
		),
		'footer_columns'                   => array(
			'type'        => 'select',
			'label'       => esc_html__( 'Footer Columns', 'baroque' ),
			'section'     => 'footer',
			'default'     => '6',
			'priority'    => 10,
			'choices'     => array(
				'2' => esc_html__( '2 Columns', 'baroque' ),
				'3' => esc_html__( '3 Columns', 'baroque' ),
				'4' => esc_html__( '4 Columns', 'baroque' ),
				'5' => esc_html__( '5 Columns', 'baroque' ),
				'6' => esc_html__( '6 Columns', 'baroque' ),
			),
			'description' => esc_html__( 'Go to Appearance/Widgets/Footer 1, 2, 3, 4, 5, 6 to add widgets content.', 'baroque' ),
		),
		'footer_custom_2'                  => array(
			'type'    => 'custom',
			'section' => 'footer',
			'default' => '<hr/>',
		),
		'footer_newsletter'                => array(
			'type'     => 'toggle',
			'label'    => esc_html__( 'Newsletter', 'baroque' ),
			'section'  => 'footer',
			'default'  => 0,
			'priority' => 10,
		),
		'newsletter_title'                 => array(
			'type'            => 'text',
			'label'           => esc_html__( 'Newsletter Title', 'baroque' ),
			'section'         => 'footer',
			'default'         => esc_html__( 'OUR NEWSLETTER', 'baroque' ),
			'priority'        => 10,
			'active_callback' => array(
				array(
					'setting'  => 'footer_newsletter',
					'operator' => '==',
					'value'    => true,
				),
			),
		),
		'newsletter_desc'                  => array(
			'type'            => 'textarea',
			'label'           => esc_html__( 'Newsletter Description', 'baroque' ),
			'section'         => 'footer',
			'default'         => esc_html__( 'Get information about new articles and discounts', 'baroque' ),
			'priority'        => 10,
			'active_callback' => array(
				array(
					'setting'  => 'footer_newsletter',
					'operator' => '==',
					'value'    => true,
				),
			),
		),
		'newsletter_form'                  => array(
			'type'            => 'textarea',
			'label'           => esc_html__( 'Newsletter Form', 'baroque' ),
			'section'         => 'footer',
			'default'         => '',
			'priority'        => 10,
			'description'     => esc_html__( 'Go to MailChimp for WP/Form to get shortcode', 'baroque' ),
			'active_callback' => array(
				array(
					'setting'  => 'footer_newsletter',
					'operator' => '==',
					'value'    => true,
				),
			),
		),
	);

	$settings['panels']   = apply_filters( 'baroque_customize_panels', $panels );
	$settings['sections'] = apply_filters( 'baroque_customize_sections', $sections );
	$settings['fields']   = apply_filters( 'baroque_customize_fields', $fields );

	return $settings;
}

$baroque_customize = new Baroque_Customize( baroque_customize_settings() );

// Fix downloaded fonts from Google.
if ( defined( 'KIRKI_VERSION' ) && version_compare( KIRKI_VERSION, '5.0.0', '<=' ) ) {

	/**
	 * Change the http request headers of 'user-agent' to download .woff2 fonts frm Google.
	 *
	 * @param  array $args
	 * @param  string $url
	 *
	 * @return array
	 */
	function baroque_fix_kirki_fonts_request_headers( $args, $url ) {
		if ( false === strpos( $url, 'https://fonts.googleapis.com/css' ) ) {
			return $args;
		}

		if ( isset( $args['user-agent'] ) && $args['user-agent'] == 'Mozilla/5.0 (Macintosh; Intel Mac OS X 10_10_5) AppleWebKit/603.3.8 (KHTML, like Gecko) Version/10.1.2 Safari/603.3.8' ) {
			$args['user-agent'] = 'Mozilla/5.0 (X11; Ubuntu; Linux x86_64; rv:73.0) Gecko/20100101 Firefox/73.0';
		}

		return $args;
	}

	add_filter( 'http_request_args', 'baroque_fix_kirki_fonts_request_headers', 10, 2 );

	/**
	 * Fix incorrect fonts files downloaded from Google.
	 * Delete the Kirki's transients to force downloading font files again.
	 *
	 * @return void
	 */
	function baroque_fix_kirki_fonts() {
		delete_transient( 'kirki_remote_url_contents' );
	}

	add_action( 'after_switch_theme', 'baroque_fix_kirki_fonts' );
	add_action( 'wp_ajax_kirki_clear_font_cache', 'baroque_fix_kirki_fonts' );
}