<?php
/**
 * Hooks for frontend display
 *
 * @package Baroque
 */


/**
 * Adds custom classes to the array of body classes.
 *
 * @since 1.0
 *
 * @param array $classes Classes for the body element.
 *
 * @return array
 */
function baroque_body_classes( $classes ) {
	$theme_version = baroque_get_option( 'theme_version' );
	$header_layout = baroque_get_option( 'header_layout' );
	$header_color  = baroque_get_option( 'header_text_color' );
	$f_layout      = baroque_get_option( 'footer_layout' );
	$p_style       = baroque_get_option( 'portfolio_style' );
	$p_type_nav    = baroque_get_option( 'portfolio_type_nav' );

	if ( get_post_meta( get_the_ID(), 'custom_footer_layout', true ) ) {
		$f_layout = get_post_meta( get_the_ID(), 'footer_layout', true );
	}

	// Adds a class of group-blog to blogs with more than 1 published author.
	if ( is_multi_author() ) {
		$classes[] = 'group-blog';
	}

	// Adds a class of hfeed to non-singular pages.
	if ( ! is_singular() ) {
		$classes[] = 'hfeed';
	}

	if ( is_singular( 'post' ) ) {
		$classes[] = baroque_get_option( 'single_post_layout' );

		if ( ! intval( baroque_get_option( 'show_post_format' ) ) ||
			( ! baroque_single_post_has_post_format() )
		) {
			$classes[] = 'hide-post-format';
		}

	} elseif ( baroque_is_blog() ) {
		$classes[] = 'baroque-blog-page';
		$classes[] = 'blog-' . baroque_get_option( 'blog_style' );
		$classes[] = baroque_get_option( 'blog_layout' );

	} elseif ( baroque_is_portfolio() ) {
		$classes[] = 'baroque-portfolio-page';
		$classes[] = 'portfolio-' . $p_style;

		if ( $p_style == 'metro' ) {
			$classes[] = 'portfolio-masonry';
		}

		if ( $p_style != 'carousel' ) {
			$classes[] = 'portfolio-nav-' . $p_type_nav;
		}

	} elseif ( is_singular( 'portfolio' ) ) {
		$portfolio_layout = baroque_get_option( 'single_portfolio_layout' );

		if ( get_post_meta( get_the_ID(), 'custom_portfolio_layout', true ) ) {
			$portfolio_layout = get_post_meta( get_the_ID(), 'portfolio_layout', true );
		}

		$classes[] = 'single-portfolio-layout-' . $portfolio_layout;

	} else {
		$classes[] = baroque_get_layout();
	}

	if ( baroque_is_catalog() ) {
		$classes[] = 'baroque-catalog-page';
	}
	if ( $f_layout != '3' && intval( baroque_get_option( 'footer_fixed' ) ) ) {
		$classes[] = 'footer-fixed';
	}

	if ( is_search() ) {
		$classes[] = 'blog-classic';
	}

	if ( intval( baroque_get_option( 'header_sticky' ) ) ) {
		$classes[] = 'header-sticky';

		if ( intval( baroque_get_option( 'sticky_header_background' ) ) ) {
			$classes[] = 'header-sticky-bg';
		}
	}

	if ( baroque_is_homepage() ) {
		$classes[] = 'header-' . $header_color;
	}

	if (
		baroque_is_homepage()
		&& baroque_get_option( 'header_transparent' )
	) {
		$classes[] = 'header-transparent';
	}

	$classes[] = 'baroque-' . $theme_version;

	$classes[] = 'header-' . $header_layout;

	$classes[] = 'footer-' . $f_layout;

	return $classes;
}

add_filter( 'body_class', 'baroque_body_classes' );


if ( ! function_exists( 'baroque_get_layout' ) ) :
	/**
	 * Get layout base on current page
	 *
	 * @return string
	 */
	function baroque_get_layout() {
		$layout = 'full-content';

		if ( is_404() ) {
			$layout = 'full-content';
		} elseif ( is_singular( 'post' ) ) {
			if ( get_post_meta( get_the_ID(), 'custom_page_layout', true ) ) {
				$layout = get_post_meta( get_the_ID(), 'layout', true );
			} else {
				$layout = baroque_get_option( 'single_post_layout' );
			}
		} elseif ( baroque_is_page_template() ) {
			$layout = 'full-content';
		} elseif ( is_page() ) {
			if ( get_post_meta( get_the_ID(), 'custom_page_layout', true ) ) {
				$layout = get_post_meta( get_the_ID(), 'layout', true );
			} else {
				$layout = baroque_get_option( 'page_layout' );
			}
		} elseif ( is_singular( 'portfolio' ) || baroque_is_portfolio() ) {
			$layout = 'full-content';
		} elseif ( is_singular( 'service' ) || baroque_is_service() ) {
			$layout = 'full-content';
		} elseif ( baroque_is_catalog() ) {
			$layout = baroque_get_option( 'catalog_layout' );
		} elseif ( function_exists( 'is_product' ) && is_product() ) {
			$layout = 'full-content';
		} elseif ( baroque_is_blog() || is_search() ) {
			$layout = 'full-content';

			if ( 'classic' == baroque_get_option( 'blog_style' ) ) {
				$layout = baroque_get_option( 'blog_layout' );
			}
		}

		return apply_filters( 'baroque_site_layout', $layout );
	}

endif;

if ( ! function_exists( 'baroque_get_content_columns' ) ) :
	/**
	 * Get CSS classes for content columns
	 *
	 * @param string $layout
	 *
	 * @return array
	 */
	function baroque_get_content_columns( $layout = null ) {
		$layout = $layout ? $layout : baroque_get_layout();

		if ( 'full-content' == $layout ) {
			return array( 'col-md-12', 'col-sm-12', 'col-xs-12' );
		}

		if ( baroque_is_catalog() ) {
			return array( 'col-md-9', 'col-sm-12', 'col-xs-12' );

		} else {
			if ( 'sidebar-content' == $layout ) {
				return array( 'col-md-8', 'col-md-offset-1', 'col-sm-12', 'col-xs-12' );
			}

			return array( 'col-md-8', 'col-sm-12', 'col-xs-12' );
		}

	}

endif;


if ( ! function_exists( 'baroque_content_columns' ) ) :

	/**
	 * Display CSS classes for content columns
	 *
	 * @param string $layout
	 */
	function baroque_content_columns( $layout = null ) {
		echo implode( ' ', baroque_get_content_columns( $layout ) );
	}

endif;
